@@ -46,14 +46,17 @@ public:
     }
 
     virtual ~NeonSessionWrapper() {
-        if(_sess->get_ne_sess() != NULL){
+        if(_sess && _sess->get_ne_sess() != NULL){
             ne_unhook_pre_send(_sess->get_ne_sess(), NeonSessionWrapper::runHookPreSend, (void*) this);
             ne_unhook_post_headers(_sess->get_ne_sess(), NeonSessionWrapper::runHookPreReceive, (void*) this);
         }
     }
 
     ne_session* get_ne_sess() {
-        return _sess->get_ne_sess();
+        if (_sess) {
+            return _sess->get_ne_sess();
+        }
+        return {};
     }
 
     bool isRecycledSession() const {
@@ -61,7 +64,9 @@ public:
     }
 
     void do_not_reuse_this_session() {
-        _sess->do_not_reuse_this_session();
+        if(_sess) {
+            _sess->do_not_reuse_this_session();
+        }
     }
 
 private:
@@ -481,7 +486,17 @@ Status StandaloneNeonRequest::obtainRedirectedLocation(Uri &out) {
   const char* name = NULL, *value = NULL;
   while( (handle = ne_response_header_iterate(_neon_req, handle, &name, &value)) != NULL) {
     if(strcasecmp("location", name) == 0) {
-      out = Uri(value);
+      std::string location(value);
+      // Dealing with relative location [DMC-1209]
+      if (!location.empty() && location[0] == '/') {
+        out = Uri::fromRelativePath(_uri, location);
+      } else {
+        out = Uri(location);
+      }
+      if (out.getStatus() != StatusCode::OK) {
+        return Status(davix_scope_http_request(), out.getStatus(),
+                      fmt::format("Failed to parse redirect location: {}", out.getString()));
+      }
       return Status();
     }
   }
